.. currentmodule:: obspy.io.xseed
.. automodule:: obspy.io.xseed

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       parser.Parser

    .. comment to end block

    Modules
    -------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       core
       fields
       parser
       utils

    .. comment to end block

    Scripts
    -------
    .. autosummary::
       :template: script.rst
       :toctree: autogen
       :nosignatures:

       scripts.dataless2resp
       scripts.dataless2xseed
       scripts.xseed2dataless

    .. comment to end block
